==> eiffelstudio-18.11.10.2592.tar: F_code/C3/ew144.c <==
/*
 * Code for class EW_EIFFEL_VALIDITY_ERROR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew144.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EIFFEL_VALIDITY_ERROR}.make */
void F167_1758 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLIU(3);
	
	RTEAA("make", 166, Current, 0, 2, 1811);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.validity_code */
EIF_REFERENCE F167_1759 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {EW_EIFFEL_VALIDITY_ERROR}.summary */
EIF_REFERENCE F167_1761 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTEAA("summary", 166, Current, 1, 0, 1814);
	RTGC;
	RTHOOK(1);
	Result = RTMS32_EX_H("V\000\000\000a\000\000\000l\000\000\000i\000\000\000d\000\000\000i\000\000\000t\000\000\000y\000\000\000 \000\000\000e\000\000\000r\000\000\000r\000\000\000o\000\000\000r\000\000\000",14,1957253234);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4163[Dtype(tr1)-880])(RTCW(tr1));
	if ((EIF_BOOLEAN) !tb1) {
		RTHOOK(3);
		tr1 = RTMS32_EX_H(" \000\000\000i\000\000\000n\000\000\000 \000\000\000c\000\000\000l\000\000\000a\000\000\000s\000\000\000s\000\000\000 \000\000\000",10,533636896);
		F882_5713(RTCW(Result), tr1);
		RTHOOK(4);
		F882_5713(RTCW(Result), *(EIF_REFERENCE *)(Current));
	}
	RTHOOK(5);
	tr1 = RTMS32_EX_H(" \000\000\000c\000\000\000o\000\000\000d\000\000\000e\000\000\000 \000\000\000",6,1932525344);
	F882_5713(RTCW(Result), tr1);
	RTHOOK(6);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(7);
		F882_5713(RTCW(Result), loc1);
	}
	RTHOOK(8);
	if (F166_1751(Current)) {
		RTHOOK(9);
		tr1 = RTMS32_EX_H(" \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000i\000\000\000n\000\000\000e\000\000\000 \000\000\000",9,1997649184);
		F882_5713(RTCW(Result), tr1);
		RTHOOK(10);
		F882_5717(RTCW(Result), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_));
	}
	RTHOOK(11);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.is_equal */
EIF_BOOLEAN F167_1762 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("is_equal", 166, Current, 0, 1, 1815);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	if (F166_1754(Current, arg1)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = F880_5626(RTCW(tr1), tr2);
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.is_less */
EIF_BOOLEAN F167_1763 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("is_less", 166, Current, 0, 1, 1816);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	tb1 = '\01';
	tr1 = *(EIF_REFERENCE *)(Current);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
	tb2 = F880_5628(RTCW(tr1), tr2);
	if (!tb2) {
		tb2 = '\0';
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
		tb3 = F880_5626(RTCW(tr1), tr2);
		if (tb3) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tb3 = F880_5628(RTCW(tr1), tr2);
			tb2 = tb3;
		}
		tb1 = tb2;
	}
	if (!tb1) {
		tb1 = '\0';
		tb2 = '\0';
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
		tb3 = F880_5626(RTCW(tr1), tr2);
		if (tb3) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tb3 = F880_5626(RTCW(tr1), tr2);
			tb2 = tb3;
		}
		if (tb2) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_0_0_0_);
			tb1 = (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) < ti4_1);
		}
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.matches_pattern */
EIF_BOOLEAN F167_1764 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("matches_pattern", 166, Current, 0, 1, 1817);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	if (F166_1756(Current, arg1)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = F880_5626(RTCW(tr1), tr2);
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit144 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C3/ew144.c <==
/*
 * Code for class EW_EIFFEL_VALIDITY_ERROR
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew144.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EIFFEL_VALIDITY_ERROR}.make */
void F167_1758 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLIU(3);
	
	RTEAA("make", 166, Current, 0, 2, 1811);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.summary */
EIF_REFERENCE F167_1761 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Result);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc1);
	RTLIU(4);
	
	RTEAA("summary", 166, Current, 1, 0, 1814);
	RTGC;
	RTHOOK(1);
	Result = RTMS32_EX_H("V\000\000\000a\000\000\000l\000\000\000i\000\000\000d\000\000\000i\000\000\000t\000\000\000y\000\000\000 \000\000\000e\000\000\000r\000\000\000r\000\000\000o\000\000\000r\000\000\000",14,1957253234);
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4184[Dtype(RTCW(tr1))-880])(tr1);
	if ((EIF_BOOLEAN) !tb1) {
		RTHOOK(3);
		tr1 = RTMS32_EX_H(" \000\000\000i\000\000\000n\000\000\000 \000\000\000c\000\000\000l\000\000\000a\000\000\000s\000\000\000s\000\000\000 \000\000\000",10,533636896);
		F882_5734(RTCW(Result), tr1);
		RTHOOK(4);
		F882_5734(RTCW(Result), *(EIF_REFERENCE *)(Current));
	}
	RTHOOK(5);
	tr1 = RTMS32_EX_H(" \000\000\000c\000\000\000o\000\000\000d\000\000\000e\000\000\000 \000\000\000",6,1932525344);
	F882_5734(RTCW(Result), tr1);
	RTHOOK(6);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc1 = tr1;
	if (EIF_TEST(loc1)) {
		RTHOOK(7);
		F882_5734(RTCW(Result), loc1);
	}
	RTHOOK(8);
	if (F166_1751(Current)) {
		RTHOOK(9);
		tr1 = RTMS32_EX_H(" \000\000\000a\000\000\000t\000\000\000 \000\000\000l\000\000\000i\000\000\000n\000\000\000e\000\000\000 \000\000\000",9,1997649184);
		F882_5734(RTCW(Result), tr1);
		RTHOOK(10);
		F882_5738(RTCW(Result), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_));
	}
	RTHOOK(11);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.is_equal */
EIF_BOOLEAN F167_1762 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("is_equal", 166, Current, 0, 1, 1815);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	if (F166_1754(Current, arg1)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = F880_5647(RTCW(tr1), tr2);
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.is_less */
EIF_BOOLEAN F167_1763 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("is_less", 166, Current, 0, 1, 1816);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	tb1 = '\01';
	tr1 = *(EIF_REFERENCE *)(Current);
	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
	tb2 = F880_5649(RTCW(tr1), tr2);
	if (!tb2) {
		tb2 = '\0';
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
		tb3 = F880_5647(RTCW(tr1), tr2);
		if (tb3) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tb3 = F880_5649(RTCW(tr1), tr2);
			tb2 = tb3;
		}
		tb1 = tb2;
	}
	if (!tb1) {
		tb1 = '\0';
		tb2 = '\0';
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
		tb3 = F880_5647(RTCW(tr1), tr2);
		if (tb3) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
			tb3 = F880_5647(RTCW(tr1), tr2);
			tb2 = tb3;
		}
		if (tb2) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_0_0_0_);
			tb1 = (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_0_) < ti4_1);
		}
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_VALIDITY_ERROR}.matches_pattern */
EIF_BOOLEAN F167_1764 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTEAA("matches_pattern", 166, Current, 0, 1, 1817);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	if (F166_1756(Current, arg1)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
		tb1 = F880_5647(RTCW(tr1), tr2);
		Result = tb1;
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit144 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
